# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.6-rc8
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist

class V1Validation(BaseModel):
    """
    V1Validation
    """
    delay: Optional[StrictBool] = None
    gt: Optional[StrictInt] = None
    ge: Optional[StrictInt] = None
    lt: Optional[StrictInt] = None
    le: Optional[StrictInt] = None
    multiple_of: Optional[StrictInt] = Field(None, alias="multipleOf")
    min_digits: Optional[StrictInt] = Field(None, alias="minDigits")
    max_digits: Optional[StrictInt] = Field(None, alias="maxDigits")
    decimal_places: Optional[StrictInt] = Field(None, alias="decimalPlaces")
    regex: Optional[StrictStr] = None
    min_length: Optional[StrictInt] = Field(None, alias="minLength")
    max_length: Optional[StrictInt] = Field(None, alias="maxLength")
    contains: Optional[conlist(Dict[str, Any])] = None
    excludes: Optional[conlist(Dict[str, Any])] = None
    options: Optional[conlist(Dict[str, Any])] = None
    min_items: Optional[StrictInt] = Field(None, alias="minItems")
    max_items: Optional[StrictInt] = Field(None, alias="maxItems")
    keys: Optional[conlist(StrictStr)] = None
    contains_keys: Optional[conlist(StrictStr)] = Field(None, alias="containsKeys")
    excludes_keys: Optional[conlist(StrictStr)] = Field(None, alias="excludesKeys")
    __properties = ["delay", "gt", "ge", "lt", "le", "multipleOf", "minDigits", "maxDigits", "decimalPlaces", "regex", "minLength", "maxLength", "contains", "excludes", "options", "minItems", "maxItems", "keys", "containsKeys", "excludesKeys"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Validation:
        """Create an instance of V1Validation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Validation:
        """Create an instance of V1Validation from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Validation.parse_obj(obj)

        _obj = V1Validation.parse_obj({
            "delay": obj.get("delay"),
            "gt": obj.get("gt"),
            "ge": obj.get("ge"),
            "lt": obj.get("lt"),
            "le": obj.get("le"),
            "multiple_of": obj.get("multipleOf"),
            "min_digits": obj.get("minDigits"),
            "max_digits": obj.get("maxDigits"),
            "decimal_places": obj.get("decimalPlaces"),
            "regex": obj.get("regex"),
            "min_length": obj.get("minLength"),
            "max_length": obj.get("maxLength"),
            "contains": obj.get("contains"),
            "excludes": obj.get("excludes"),
            "options": obj.get("options"),
            "min_items": obj.get("minItems"),
            "max_items": obj.get("maxItems"),
            "keys": obj.get("keys"),
            "contains_keys": obj.get("containsKeys"),
            "excludes_keys": obj.get("excludesKeys")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.6-rc8
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, StrictInt, StrictStr
from polyaxon_sdk.models.v1_analytics_spec import V1AnalyticsSpec
from polyaxon_sdk.models.v1_dashboard_spec import V1DashboardSpec

class V1SearchSpec(BaseModel):
    """
    V1SearchSpec
    """
    query: Optional[StrictStr] = None
    sort: Optional[StrictStr] = None
    limit: Optional[StrictInt] = None
    offset: Optional[StrictInt] = None
    groupby: Optional[StrictStr] = None
    columns: Optional[StrictStr] = None
    layout: Optional[StrictStr] = None
    sections: Optional[StrictStr] = None
    compares: Optional[StrictStr] = None
    heat: Optional[StrictStr] = None
    events: Optional[V1DashboardSpec] = None
    histograms: Optional[Dict[str, Any]] = None
    trends: Optional[Dict[str, Any]] = None
    analytics: Optional[V1AnalyticsSpec] = None
    __properties = ["query", "sort", "limit", "offset", "groupby", "columns", "layout", "sections", "compares", "heat", "events", "histograms", "trends", "analytics"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1SearchSpec:
        """Create an instance of V1SearchSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of events
        if self.events:
            _dict['events'] = self.events.to_dict()
        # override the default output from pydantic by calling `to_dict()` of analytics
        if self.analytics:
            _dict['analytics'] = self.analytics.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1SearchSpec:
        """Create an instance of V1SearchSpec from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1SearchSpec.parse_obj(obj)

        _obj = V1SearchSpec.parse_obj({
            "query": obj.get("query"),
            "sort": obj.get("sort"),
            "limit": obj.get("limit"),
            "offset": obj.get("offset"),
            "groupby": obj.get("groupby"),
            "columns": obj.get("columns"),
            "layout": obj.get("layout"),
            "sections": obj.get("sections"),
            "compares": obj.get("compares"),
            "heat": obj.get("heat"),
            "events": V1DashboardSpec.from_dict(obj.get("events")) if obj.get("events") is not None else None,
            "histograms": obj.get("histograms"),
            "trends": obj.get("trends"),
            "analytics": V1AnalyticsSpec.from_dict(obj.get("analytics")) if obj.get("analytics") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.6-rc8
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1EventKind(str, Enum):
    """
    V1EventKind
    """

    """
    allowed enum values
    """
    RUN_STATUS_CREATED = 'run_status_created'
    RUN_STATUS_RESUMING = 'run_status_resuming'
    RUN_STATUS_COMPILED = 'run_status_compiled'
    RUN_STATUS_ON_SCHEDULE = 'run_status_on_schedule'
    RUN_STATUS_QUEUED = 'run_status_queued'
    RUN_STATUS_SCHEDULED = 'run_status_scheduled'
    RUN_STATUS_STARTING = 'run_status_starting'
    RUN_STATUS_RUNNING = 'run_status_running'
    RUN_STATUS_PROCESSING = 'run_status_processing'
    RUN_STATUS_STOPPING = 'run_status_stopping'
    RUN_STATUS_FAILED = 'run_status_failed'
    RUN_STATUS_STOPPED = 'run_status_stopped'
    RUN_STATUS_SUCCEEDED = 'run_status_succeeded'
    RUN_STATUS_SKIPPED = 'run_status_skipped'
    RUN_STATUS_WARNING = 'run_status_warning'
    RUN_STATUS_UNSCHEDULABLE = 'run_status_unschedulable'
    RUN_STATUS_UPSTREAM_FAILED = 'run_status_upstream_failed'
    RUN_STATUS_RETRYING = 'run_status_retrying'
    RUN_STATUS_UNKNOWN = 'run_status_unknown'
    RUN_STATUS_DONE = 'run_status_done'
    RUN_APPROVED_ACTOR = 'run_approved_actor'
    RUN_INVALIDATED_ACTOR = 'run_invalidated_actor'
    RUN_NEW_ARTIFACTS = 'run_new_artifacts'
    CONNECTION_GIT_COMMIT = 'connection_git_commit'
    CONNECTION_DATASET_VERSION = 'connection_dataset_version'
    CONNECTION_REGISTRY_IMAGE = 'connection_registry_image'
    ALERT_INFO = 'alert_info'
    ALERT_WARNING = 'alert_warning'
    ALERT_CRITICAL = 'alert_critical'
    MODEL_VERSION_NEW_METRIC = 'model_version_new_metric'
    PROJECT_CUSTOM_EVENT = 'project_custom_event'
    ORG_CUSTOM_EVENT = 'org_custom_event'




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.6-rc8
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1ArtifactKind(str, Enum):
    """
    - model: Model asset/event  - audio: Audio asset/event  - video: Vidio asset/event  - histogram: Histogram asset/event  - image: Image asset/event  - tensor: Tensor asset/event  - dataframe: Dataframe asset/event  - chart: plotly/bokeh/vega chart  - csv: Comma separated values  - tsv: Tab separated values  - psv: Pipe separated values  - ssv: Space separated values  - metric: Metric asset/event  - env: Env file  - html: HTML asset/event  - text: Text asset/event  - file: File asset/lineage  - dir: Dir asset/lineage  - dockerfile: Dockerfile asset  - docker_image: Docker image  - data: Data asset/event  - coderef: Coderef lineage  - table: Table asset/event  - tensorboard: Tensorboard lineage  - curve: Curve event  - confusion: Confusion matrix event  - analysis: Analysis lineage  - iteration: Iteration lineage  - markdown: Mardown event  - system: System event  - span: Trace/Span event  - artifact: Generic artifact
    """

    """
    allowed enum values
    """
    MODEL = 'model'
    AUDIO = 'audio'
    VIDEO = 'video'
    HISTOGRAM = 'histogram'
    IMAGE = 'image'
    TENSOR = 'tensor'
    DATAFRAME = 'dataframe'
    CHART = 'chart'
    CSV = 'csv'
    TSV = 'tsv'
    PSV = 'psv'
    SSV = 'ssv'
    METRIC = 'metric'
    ENV = 'env'
    HTML = 'html'
    TEXT = 'text'
    FILE = 'file'
    DIR = 'dir'
    DOCKERFILE = 'dockerfile'
    DOCKER_IMAGE = 'docker_image'
    DATA = 'data'
    CODEREF = 'coderef'
    TABLE = 'table'
    TENSORBOARD = 'tensorboard'
    CURVE = 'curve'
    CONFUSION = 'confusion'
    ANALYSIS = 'analysis'
    ITERATION = 'iteration'
    MARKDOWN = 'markdown'
    SYSTEM = 'system'
    SPAN = 'span'
    ARTIFACT = 'artifact'




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.6-rc8
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from polyaxon_sdk.models.v1_clean_pod_policy import V1CleanPodPolicy
from polyaxon_sdk.models.v1_kf_replica import V1KFReplica
from polyaxon_sdk.models.v1_scheduling_policy import V1SchedulingPolicy

class V1PytorchJob(BaseModel):
    """
    V1PytorchJob
    """
    kind: Optional[StrictStr] = 'pytorchjob'
    clean_pod_policy: Optional[V1CleanPodPolicy] = Field(None, alias="cleanPodPolicy")
    scheduling_policy: Optional[V1SchedulingPolicy] = Field(None, alias="schedulingPolicy")
    master: Optional[V1KFReplica] = None
    worker: Optional[V1KFReplica] = None
    __properties = ["kind", "cleanPodPolicy", "schedulingPolicy", "master", "worker"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1PytorchJob:
        """Create an instance of V1PytorchJob from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of scheduling_policy
        if self.scheduling_policy:
            _dict['schedulingPolicy'] = self.scheduling_policy.to_dict()
        # override the default output from pydantic by calling `to_dict()` of master
        if self.master:
            _dict['master'] = self.master.to_dict()
        # override the default output from pydantic by calling `to_dict()` of worker
        if self.worker:
            _dict['worker'] = self.worker.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1PytorchJob:
        """Create an instance of V1PytorchJob from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1PytorchJob.parse_obj(obj)

        _obj = V1PytorchJob.parse_obj({
            "kind": obj.get("kind") if obj.get("kind") is not None else 'pytorchjob',
            "clean_pod_policy": obj.get("cleanPodPolicy"),
            "scheduling_policy": V1SchedulingPolicy.from_dict(obj.get("schedulingPolicy")) if obj.get("schedulingPolicy") is not None else None,
            "master": V1KFReplica.from_dict(obj.get("master")) if obj.get("master") is not None else None,
            "worker": V1KFReplica.from_dict(obj.get("worker")) if obj.get("worker") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.6-rc8
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from polyaxon_sdk.models.v1_param import V1Param
from polyaxon_sdk.models.v1_statuses import V1Statuses

class V1Hook(BaseModel):
    """
    V1Hook
    """
    hub_ref: Optional[StrictStr] = Field(None, alias="hubRef")
    connection: Optional[StrictStr] = None
    trigger: Optional[V1Statuses] = None
    conditions: Optional[StrictStr] = None
    params: Optional[Dict[str, V1Param]] = None
    queue: Optional[StrictStr] = None
    presets: Optional[conlist(StrictStr)] = None
    disable_defaults: Optional[StrictBool] = Field(None, alias="disableDefaults")
    __properties = ["hubRef", "connection", "trigger", "conditions", "params", "queue", "presets", "disableDefaults"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Hook:
        """Create an instance of V1Hook from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each value in params (dict)
        _field_dict = {}
        if self.params:
            for _key in self.params:
                if self.params[_key]:
                    _field_dict[_key] = self.params[_key].to_dict()
            _dict['params'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Hook:
        """Create an instance of V1Hook from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Hook.parse_obj(obj)

        _obj = V1Hook.parse_obj({
            "hub_ref": obj.get("hubRef"),
            "connection": obj.get("connection"),
            "trigger": obj.get("trigger"),
            "conditions": obj.get("conditions"),
            "params": dict((_k, V1Param.from_dict(_v)) for _k, _v in obj.get("params").items()) if obj.get("params") is not None else None,
            "queue": obj.get("queue"),
            "presets": obj.get("presets"),
            "disable_defaults": obj.get("disableDefaults")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.6-rc8
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1EventChartKind(str, Enum):
    """
    - plotly: Plotly chart  - bokeh: Bokeh chart  - vega: Vega chart
    """

    """
    allowed enum values
    """
    PLOTLY = 'plotly'
    BOKEH = 'bokeh'
    VEGA = 'vega'




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.6-rc8
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class SearchView(str, Enum):
    """
    - any: Any view  - runs: Runs view  - selection: Selection view  - analytics: Analytics view  - components: Components view  - models: Models view  - artifacts: Artifacts view  - projects: Projects view
    """

    """
    allowed enum values
    """
    ANY = 'any'
    RUNS = 'runs'
    SELECTION = 'selection'
    ANALYTICS = 'analytics'
    COMPONENTS = 'components'
    MODELS = 'models'
    ARTIFACTS = 'artifacts'
    PROJECTS = 'projects'




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.6-rc8
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1Statuses(str, Enum):
    """
    V1Statuses
    """

    """
    allowed enum values
    """
    CREATED = 'created'
    RESUMING = 'resuming'
    ON_SCHEDULE = 'on_schedule'
    COMPILED = 'compiled'
    QUEUED = 'queued'
    SCHEDULED = 'scheduled'
    STARTING = 'starting'
    RUNNING = 'running'
    PROCESSING = 'processing'
    STOPPING = 'stopping'
    FAILED = 'failed'
    STOPPED = 'stopped'
    SUCCEEDED = 'succeeded'
    SKIPPED = 'skipped'
    WARNING = 'warning'
    UNSCHEDULABLE = 'unschedulable'
    UPSTREAM_FAILED = 'upstream_failed'
    RETRYING = 'retrying'
    UNKNOWN = 'unknown'
    DONE = 'done'




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.6-rc8
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, conlist
from polyaxon_sdk.models.v1_run import V1Run
from polyaxon_sdk.models.v1_run_edge_kind import V1RunEdgeKind
from polyaxon_sdk.models.v1_statuses import V1Statuses

class V1RunEdge(BaseModel):
    """
    V1RunEdge
    """
    upstream: Optional[V1Run] = None
    downstream: Optional[V1Run] = None
    kind: Optional[V1RunEdgeKind] = None
    values: Optional[Dict[str, Any]] = None
    statuses: Optional[conlist(V1Statuses)] = None
    __properties = ["upstream", "downstream", "kind", "values", "statuses"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1RunEdge:
        """Create an instance of V1RunEdge from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of upstream
        if self.upstream:
            _dict['upstream'] = self.upstream.to_dict()
        # override the default output from pydantic by calling `to_dict()` of downstream
        if self.downstream:
            _dict['downstream'] = self.downstream.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1RunEdge:
        """Create an instance of V1RunEdge from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1RunEdge.parse_obj(obj)

        _obj = V1RunEdge.parse_obj({
            "upstream": V1Run.from_dict(obj.get("upstream")) if obj.get("upstream") is not None else None,
            "downstream": V1Run.from_dict(obj.get("downstream")) if obj.get("downstream") is not None else None,
            "kind": obj.get("kind"),
            "values": obj.get("values"),
            "statuses": obj.get("statuses")
        })
        return _obj

